@@ -12,7 +12,7 @@ class LinearProgress(ValueElement):
         """Linear Progress
 
         A linear progress bar wrapping Quasar's
-        `QLinearProgress <https://v1.quasar.dev/vue-components/linear-progress>`_ component.
+        `QLinearProgress <https://quasar.dev/vue-components/linear-progress>`_ component.
 
         :param value: the initial value of the field (from 0.0 to 1.0)
         :param size: the height of the progress bar (default: "20px" with value label and "4px" without)
@@ -34,7 +34,7 @@ class CircularProgress(ValueElement):
         """Circular Progress
 
         A circular progress bar wrapping Quasar's
-        `QCircularProgress <https://v1.quasar.dev/vue-components/circular-progress>`_.
+        `QCircularProgress <https://quasar.dev/vue-components/circular-progress>`_.
 
         :param value: the initial value of the field
         :param size: the size of the progress circle (default: "xl")
