@@ -4,7 +4,6 @@ from inspect import signature
 from typing import TYPE_CHECKING, Any, BinaryIO, Callable, List, Optional, Union
 
 from . import background_tasks, globals
-from .async_updater import AsyncUpdater
 from .helpers import is_coroutine
 
 if TYPE_CHECKING:
@@ -273,7 +272,7 @@ def handle_event(handler: Optional[Callable],
         if is_coroutine(handler):
             async def wait_for_result():
                 with sender.parent_slot:
-                    await AsyncUpdater(result)
+                    await result
             if globals.loop and globals.loop.is_running():
                 background_tasks.create(wait_for_result(), name=str(handler))
             else:
