@@ -1,6 +1,6 @@
 from typing import Optional, Union
 
-from .. import background_tasks, globals
+from .. import globals, outbox
 
 
 def notify(message: str, *,
@@ -23,4 +23,4 @@ def notify(message: str, *,
     Note: You can pass additional keyword arguments according to `Quasar's Notify API <https://quasar.dev/quasar-plugins/notify#notify-api>`_.
     """
     options = {key: value for key, value in locals().items() if not key.startswith('_') and value is not None}
-    background_tasks.create(globals.sio.emit('notify', options, room=globals.get_client().id))
+    outbox.enqueue_message('notify', options, globals.get_client().id)
