@@ -4,7 +4,6 @@ import traceback
 from typing import Callable
 
 from .. import background_tasks, globals
-from ..async_updater import AsyncUpdater
 from ..binding import BindableProperty
 from ..helpers import is_coroutine
 
@@ -75,7 +74,7 @@ class Timer:
         try:
             result = self.callback()
             if is_coroutine(self.callback):
-                await AsyncUpdater(result)
+                await result
         except Exception:
             traceback.print_exc()
 
