@@ -27,11 +27,13 @@ server: Server
 loop: Optional[asyncio.AbstractEventLoop] = None
 log: logging.Logger = logging.getLogger('nicegui')
 state: State = State.STOPPED
+ui_run_has_been_called: bool = False
 
 host: str
 port: int
 reload: bool
 title: str
+viewport: str
 favicon: Optional[str]
 dark: Optional[bool]
 binding_refresh_interval: float
